Learn R Programming

georob (version 0.2-3)

default.aniso: Setting Default Values of Variogram Parameters

Description

Helper functions to set sensible default values for anisotropy parameters and for controlling what variogram and anisotropy parameters should be estimated.

Usage

default.aniso(f1 = 1., f2 = 1., omega = 90., phi = 90., zeta = 0.)
default.fit.param( variance = TRUE, snugget = FALSE, nugget = TRUE, scale = TRUE, alpha = FALSE, beta = FALSE, delta = FALSE, gamma = FALSE, kappa = FALSE, lambda = FALSE, mu = FALSE, nu = FALSE) default.fit.aniso(f1 = FALSE, f2 = FALSE, omega = FALSE, phi = FALSE, zeta = FALSE)

Arguments

variance
variance (sill $\sigma^2$) of the auto-correlated component of the Gaussian random field $B(s)$.
snugget
variance (spatial nugget $\sigma^2_n$) of the seemingly spatially uncorrelated component of $B(s)$ (micro-scale spatial variation; default value snugget = 0).
nugget
variance (nugget $\tau^2$) of the independent errors $\epsilon(s)$.
scale
range parameter ($\alpha$) of the variogram.
alpha, beta, delta, gamma, kappa, lambda, mu, nu
names of additional variogram parameters such as the smoothness parameter $\nu$ of the Whittle-Matérn model (see RMmodel and param.names).
f1
ratio $f_1$ of lengths of second and first semi-principal axes of an ellipsoidal surface with constant semivariance in $R^3$ (default f1 = 1).
f2
ratio $f_2$ of lengths of third and first semi-principal axes of the semivariance ellipsoid (default f2 = 1).
omega
azimuth in degrees of the first semi-principal axis of the semivariance ellipsoid (default omega = 90).
phi
90 degrees minus altitude of the first semi-principal axis of the semivariance ellipsoid (default phi = 90).
zeta
angle in degrees between the second semi-principal axis and the direction of the line defined by the intersection between the $x$-$y$-plane and the plane orthogonal to the first semi-principal axis of the semivariance ellipsoid through the origin (default zeta = 0).

Value

Either a named numeric with initial values of anisotropy parameters (default.aniso) or named logical vector, controlling what parameters should be estimated (default.fit.param default.fit.aniso).

See Also

georobIntro for a description of the model and a brief summary of the algorithms; georob for (robust) fitting of spatial linear models.

Examples

Run this code
default.aniso(f1 = 0.5, omega = 45)
default.fit.param(scale=FALSE, alpha = TRUE)
default.fit.aniso(f1 = TRUE, omega = TRUE)

Run the code above in your browser using DataLab