Usage
pmm(A, B, control = control.pmm())
control.pmm(ncores = 1, max.ncores = detectCores(), f = 2, sfstop = FALSE, allow.recursive = TRUE, ...)
Arguments
A, B
matrices to be mulitplied.
control
a list of with the arguments ncores, f, and
sfstop or a function such as control.pmm that generates such
a list.
ncores
number (integer, default 1) of cores used for parallelized
matrix multiplication.
max.ncores
maximum number of cores (integer, default all cores of
a machine) used for parallelized computations.
f
number (integer, default 2) of tasks assigned on non-Windows OS
to each core in parallelized matrix multiplication.
sfstop
logical controlling whether the SNOW socket cluster is
stopped after each parallelized matrix multiplication on windows OS
(default FALSE).
allow.recursive
logical controlling whether nested parallelized
computation should be allowed (default TRUE).
...
further arguments, currently not used.