Learn R Programming

georob (version 0.3-14)

wolfcamp: Wolfcamp Aquifer Data

Description

Piezometric head measurements taken at the Wolfcamp Aquifer, Texas, USA. See Cressie (1993, p. 212--214) for description of the scientific problem and the data. Original data were converted to SI units: coordinates are given in kilometers and pressure heads in meters.

Usage

data(wolfcamp)

Arguments

Format

A data frame with 85 observations on the following 3 variables:

x

a numeric vector with the easting coordinate in kilometers.

y

a numeric vector with the northing coordinate in kilometers.

pressure

a numeric vector with the piezometric head in meters.

References

Cressie, N.A.C (1993) Statistics for Spatial Data. New York: Wiley.

Papritz, A. and Moyeed, R. (2001) Parameter uncertainty in spatial prediction: checking its importance by cross-validating the Wolfcamp and Rongelap data sets. GeoENV 2000: Geostatistical for Environmental Applications. Ed. P. Monestiez, D. Allard, R. Froidevaux. Kluwer.

Examples

Run this code
# NOT RUN {
data(wolfcamp)
summary(wolfcamp)
# }

Run the code above in your browser using DataLab