georob. It
describes the arguments of the functions control.georob,
param.transf, fwd.transf, dfwd.transf,
bwd.transf, control.rq, control.nleqslv,
control.nlminb and control.optim, which all serve to
control the behaviour of georob.control.georob(ml.method = c("REML", "ML"), reparam = TRUE, maximizer = c("nlminb", "optim"), initial.param = TRUE, initial.fixef = c("lmrob", "rq", "lm"), bhat = NULL, min.rweight = 0.25, param.tf = param.transf(), fwd.tf = fwd.transf(), deriv.fwd.tf = dfwd.transf(), bwd.tf = bwd.transf(), safe.param = 1.e12, psi.func = c("logistic", "t.dist", "huber"), tuning.psi.nr = 1000, irwls.initial = TRUE, irwls.maxiter = 50, irwls.ftol = 1.e-5, force.gradient = FALSE, min.condnum = 1.e-12, zero.dist = sqrt(.Machine[["double.eps"]]), error.family.estimation = c("gaussian", "long.tailed"), error.family.cov.effects = c("gaussian", "long.tailed"), error.family.cov.residuals = c("long.tailed", "gaussian"), cov.bhat = FALSE, full.cov.bhat = FALSE, cov.betahat = TRUE, cov.bhat.betahat = FALSE, cov.delta.bhat = TRUE, full.cov.delta.bhat = TRUE, cov.delta.bhat.betahat = TRUE, cov.ehat = TRUE, full.cov.ehat = FALSE, cov.ehat.p.bhat = FALSE, full.cov.ehat.p.bhat = FALSE, aux.cov.pred.target = FALSE, hessian = TRUE, rq = control.rq(), lmrob = lmrob.control(), nleqslv = control.nleqslv(), optim = control.optim(), nlminb = control.nlminb(), pmm = control.pmm(), ...)
param.transf(variance = "log", snugget = "log", nugget = "log", scale = "log", alpha = c( RMaskey = "log", RMdewijsian = "logit2", RMfbm = "logit2", RMgencauchy = "logit2", RMgenfbm = "logit2", RMlgd = "identity", RMqexp = "logit1", RMstable = "logit2" ), beta = c(RMdagum = "logit1", RMgencauchy = "log", RMlgd = "log"), delta = "logit1", gamma = c(RMcauchy = "log", RMdagum = "logit1"), kappa = "logit3", lambda = "log", mu = "log", nu = "log", f1 = "log", f2 ="log", omega = "identity", phi = "identity", zeta = "identity")
fwd.transf(...)
dfwd.transf(...)
bwd.transf(...)
control.rq(tau = 0.5, rq.method = "br", rq.alpha = 0.1, ci = FALSE, iid = TRUE, interp = TRUE, tcrit = TRUE, rq.beta = 0.99995, eps = 1e-06, Mm.factor = 0.8, max.bad.fixup = 3, ...)
control.nleqslv(method = c("Broyden", "Newton"), global = c("dbldog", "pwldog", "qline", "gline", "none"), xscalm = c("fixed", "auto"), control = list(ftol = 1e-04), ...)
control.optim(method = c("BFGS", "Nelder-Mead", "CG", "L-BFGS-B", "SANN", "Brent"), lower = -Inf, upper = Inf, control = list(reltol = 1e-05), ...)
control.nlminb(control = list(rel.tol = 1.e-5), lower = -Inf, upper = Inf, ...)ML) or restricted maximum likelihood (REML
default) estimates will be computed (ignored if
tuning.psi <= tuning.psi.nr<="" code="">).=>TRUE (default) the reparametrized
variance parameters $\sigma_Z^2$, $\eta$ and $\xi$ are
estimated by Gaussian (RE)ML, otherwise the original parameters
$\tau^2$, $\sigma_n^2$ and $\sigma^2$
(cf. subsection Estimating variance parameters by Gaussian
(RE)ML, section Details of georob).initial.param = TRUE
(default) robust initial values of parameters are computed by discarding
outlying observations based on the robustness weights of the
initial fit of the regression model by lmrob
and fitting the spatial linear model by Gaussian REML to the pruned data
set. For initial.param = FALSE no initial parameter values are
computed and the estimating equations are solved with the initial values
passed by param and aniso to georob (see
Details of georob.bhat is equal to NULL (default).param.transf, which returns a
named vector of character strings that define the transformations to be
applied to the variogram parameters for model fitting, see
Details.fwd.transf, which returns a named
list of invertible functions to be used to transform variogram
parameters, see Details.dfwd.transf, which
returns a named list of functions corresponding to the first derivatives
of fwd.tf, see Details.bwd.transf, which returns the
named list of inverse functions corresponding to fwd.tf, see
Details."logistic" (a
scaled and shifted logistic cdf, default), "t.dist" (re-descending
$\psi_c$-function associated with Student $t$-distribution with
$c$ degrees of freedom) and "huber" (Huber's
$\psi_c$-function).tuning.psi is less than
tuning.psi.nr then the model is fitted robustly by solving the
robustified estimating equations, and for tuning.psi equal to or
larger than tuning.psi.nr the Gaussian (restricted) loglikelihood is
maximized (default 1000).TRUE (default) the estimating
equations of $B$ and
$\beta$ are always solved by
IRWLS from the initial estimates of
$hatB$ and
$hat\beta$. If
FALSE then IRWLS starts from respective estimates computed for the
variogram parameter estimates of the previous iteration of nleqslv
or optim.50).ftol.FALSE).1.e-12)."gaussian") that is used to approximate the covariance of
$hatB$, see
Details."gaussian") that is used to approximate the covariances of
$hat\beta$,
$hatB$ and
$B-hatB$,
see Details."long.tailed") that is used to approximate the covariances of
$hat\epsilon=Y-X hat\beta -
hatB$ and $hat\epsilon+ hatB=Y-X
hat\beta$, see Details.georob (default FALSE).TRUE) or only the variance vector of
$hatB$ is returned (default
FALSE).TRUE).FALSE).TRUE).TRUE) or only the variance vector of
$B-hatB$ is returned (default TRUE).TRUE).TRUE).TRUE) or only the variance vector of
$hat\epsilon=Y-X hat\beta -
hatB$ is returned (default FALSE).FALSE).TRUE) or only the variance vector
of $hat\epsilon+ hatB=Y-X
hat\beta$ is returned (default FALSE).FALSE).rq or a function such as
control.rq that generates such a list (see
rq for allowed arguments).control argument of
lmrob or a function such as
lmrob.control that generates such a list (see
lmrob.control for allowed arguments).nleqslv or a function such as
control.nleqslv that generates such a list (see
nleqslv for allowed arguments).nlminb
or a function such as control.nlminb that generates such a list
(see nlminb for allowed arguments).optim or a function
such as control.optim that generates such a list (see
optim for allowed arguments).pmm or a
function such as control.pmm that generates such a list
(see control.pmm for allowed arguments).fwd.transf, dfwd.transf and
bwd.transf a named vectors of functions, extending the definition
of transformations for variogram parameters (see Details).... to rq.... to rq.Parameter transformations
The arguments param.tf, fwd.tf, deriv.fwd.tf,
bwd.tf define the transformations of the variogram parameters for
RE(ML) estimation. Implemented are currently "log",
"logit1", "logit2", "logit3" (various variants of
logit-transformation, see code of function fwd.transf) and "identity" (= no)
transformations. These are the possible values that the many arguments
of the function param.transf accept (as quoted character strings)
and these are the names of the list components returned by
fwd.transf, dfwd.transf and bwd.transf. Additional
transformations can be implemented by:
fwd.tf = fwd.transf(c(my.fun = function(x) your transformation)),
deriv.fwd.tf = dfwd.transf(c(my.fun = function(x) your derivative)),
bwd.tf = bwd.transf(c(my.fun = function(x) your back-transformation)),
param.transf the name of
the new function, e.g. variance = "my.fun".
Note the values given for the arguments of param.transf must match
the names of the functions returned by fwd.transf,
dfwd.transf and bwd.transf.
Approximation of covariances of fixed and random efffects and
residuals
The robustified estimating equations of robust REML depend on the
covariances of $hatB$.
These covariances (and the covariances of
$B-hatB$,
$hat\beta$,
$hat\epsilon$,
$hat\epsilon+ hatB$) are
approximated by expressions that in turn depend on the variances of
$\varepsilon$, $\psi(\varepsilon/\tau)$ and the expectation of
$\psi'(\varepsilon/\tau) (= \partial / \partial \varepsilon
\psi(\varepsilon/\tau))$. The arguments
error.family.estimation, error.family.cov.effects and
error.family.cov.residuals control what parametric distribution
for $\varepsilon$ is used to compute the latter quantities.
Possible options are: "gaussian" or "long.tailed". In the
latter case the pdf of $\varepsilon$ is assumed to be proportional
to $1/\tau exp(-\rho(\varepsilon/\tau))$ where $\psi(x)=\rho'(x)$.
georobIntro for a description of the model and a brief summary of the algorithms;
georob for (robust) fitting of spatial linear models;
georobObject for a description of the class georob;
plot.georob for display of RE(ML) variogram estimates;
predict.georob for computing robust kriging predictions; and finally
georobMethods for further methods for the class georob.
## Not run:
# data(meuse)
#
# r.logzn.rob <- georob(log(zinc) ~ sqrt(dist), data = meuse, locations = ~ x + y,
# variogram.model = "RMexp",
# param = c(variance = 0.15, nugget = 0.05, scale = 200),
# tuning.psi = 1, control = control.georob(cov.bhat = TRUE,
# cov.ehat.p.bhat = TRUE, initial.fixef = "rq"), verbose = 2)
#
# qqnorm(rstandard(r.logzn.rob, level = 0)); abline(0, 1)
# qqnorm(ranef(r.logzn.rob, standard = TRUE)); abline(0, 1)
# ## End(Not run)
Run the code above in your browser using DataLab